@@ -9,7 +9,7 @@
 ###  eventualne "fortune cs-KODOVANI", napr. fortune cs-ascii.
 ### Pripominky, opravy chyb a nove prispevky vlastni i nalezene muzete
 ###  posilat na adresu <letty@mrakoplas.phil.muni.cz>.
-VERZE="1.4"
+VERZE="1.6.4"
 
 ### Prefix nastavte, pokud chcete vytvorit strom jinam
 ###  nez do sve adresarove struktury
@@ -19,7 +19,7 @@ PREFIX=${PREFIX-""}
 ZDROJECZ1="zemeplocha mladik pocitace skala prislovi"
 ZDROJECZ2="stopar parafraze jerome wodehouse lodge mikulas rdvcitaty"
 ZDROJECZ3="cimrman ignac parkinson murphy josef guth"
-ZDROJECZ4="citat klasik-cz market citace stoa1"
+ZDROJECZ4="citat klasik-cz market citace stoa1 plihal vodnansky"
 ZDROJESK="klasik-sk"
 ZDROJE=${ZDROJE-"$ZDROJECZ1 $ZDROJECZ2 $ZDROJECZ3 $ZDROJECZ4 $ZDROJESK"}
 
@@ -36,6 +36,11 @@ FORTUNESDIR=$PREFIX/${FORTUNESDIR:-"/usr/share/games/fortune"}
 # [ -d "$FORTUNESDIR" ] || \
 # FORTUNESDIR=$PREFIX/${FORTUNESDIR:-"/usr/share/games/fortunes"}
 
+### wish skript fortune.tk
+GAMESDIR=$PREFIX/usr/games
+APPLNKDIR=$PREFIX/etc/X11/applnk/Games
+PIXMAPDIR=$PREFIX/usr/share/pixmaps
+
 ### Konec sekce s nastavovanim promennych
 ###
 ### Instalace
@@ -90,6 +95,15 @@ do
  fi
 done
 
+#set -x
+### wish skript a odkaz pro menu
+install -d $GAMESDIR \
+&& install -m755 fortune-cs.tk $GAMESDIR
+install -d $APPLNKDIR \
+&& install -m644 fortune-cs.desktop $APPLNKDIR
+install -d $PIXMAPDIR \
+&& install -m644 smile35x34.xpm $PIXMAPDIR
+
 ### Zkouska: funguje to?
 /usr/games/fortune $FORTUNESDIR/cs > /dev/null
 exit $?
